"use strict";

const areArraysEqual = require("./are-arrays-equal");

module.exports = function areErrorsFromSameOrigin(errors) {
	let referencePath = null;

	function checkErrors(errors, basePath = []) {
		return errors.every((error) => {
			let absolutePath = basePath.concat(error.path);

			if (referencePath == null) {
				// Whatever we encounter first is the reference path. However, we don't return `true` here; even if we assume the error's own path to be correct (since it's the reference path...), the error may still have subErrors with a different path!
				referencePath = absolutePath;
			}
			
			let subErrorsEqual = (error.subErrors != null)
				? checkErrors(error.subErrors, absolutePath)
				: true;

			let selfEqual = areArraysEqual(referencePath, absolutePath);

			return (selfEqual && subErrorsEqual);
		});
	}

	return checkErrors(errors);
};
